# Copyright (c) 2023 CNES
#
# All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE file.
"""
Get software version information
================================
"""


def release() -> str:
    """Returns the software version number"""
    return "2023.1.0"


def date() -> str:
    """Returns the creation date of this release"""
    return "13 January 2023"
